import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:win_text_editor/shared/components/tree_view.dart';

class FileNode implements TreeNode {
  @override
  final String name;
  final String path;
  @override
  final bool isDirectory;
  final bool isRoot;
  @override
  final int depth;
  @override
  List<FileNode> children;
  @override
  bool isExpanded;

  @override
  String get title => name;

  @override
  bool get isVisible => true;

  FileNode({
    required this.name,
    required this.path,
    required this.isDirectory,
    this.isRoot = false,
    this.depth = 0,
    this.isExpanded = false,
    List<FileNode>? children,
  }) : children = children ?? [];

  @override
  String get id => path;

  // 获取文件图标数据
  @override
  IconData get iconData {
    if (isDirectory) {
      return Icons.folder;
    }

    final ext = name.split('.').last.toLowerCase();

    // 常见文件类型图标映射
    switch (ext) {
      case 'pdf':
        return Icons.picture_as_pdf;
      case 'doc':
      case 'docx':
        return Icons.article;
      case 'xls':
      case 'xlsx':
        return Icons.table_chart;
      case 'ppt':
      case 'pptx':
        return Icons.slideshow;
      case 'txt':
        return Icons.text_snippet;
      case 'dart':
        return Icons.code;
      case 'js':
        return Icons.javascript;
      case 'java':
        return Icons.coffee;
      case 'py':
        return Icons.data_object;
      case 'html':
        return Icons.html;
      case 'css':
        return Icons.css;
      case 'json':
        return Icons.data_array;
      case 'png':
      case 'jpg':
      case 'jpeg':
      case 'gif':
        return Icons.image;
      case 'mp3':
      case 'wav':
        return Icons.audiotrack;
      case 'mp4':
      case 'avi':
      case 'mov':
        return Icons.videocam;
      case 'zip':
      case 'rar':
      case '7z':
        return Icons.archive;
      default:
        return Icons.insert_drive_file;
    }
  }

  // 获取构建好的图标组件
  Widget get icon {
    return Icon(iconData, color: isDirectory ? Colors.amber[700] : Colors.blue);
  }

  FileNode copyWith({
    String? name,
    String? path,
    bool? isDirectory,
    bool? isExpanded,
    bool? isRoot,
    List<FileNode>? children,
    int? depth,
  }) {
    return FileNode(
      name: name ?? this.name,
      path: path ?? this.path,
      isDirectory: isDirectory ?? this.isDirectory,
      isExpanded: isExpanded ?? this.isExpanded,
      isRoot: isRoot ?? this.isRoot,
      children: children ?? this.children,
      depth: depth ?? this.depth,
    );
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;
    return other is FileNode &&
        other.name == name &&
        other.path == path &&
        other.isDirectory == isDirectory &&
        other.isRoot == isRoot &&
        listEquals(other.children, children) &&
        other.isExpanded == isExpanded;
  }

  @override
  int get hashCode {
    return name.hashCode ^
        path.hashCode ^
        isDirectory.hashCode ^
        isRoot.hashCode ^
        children.hashCode ^
        isExpanded.hashCode;
  }
}
