import 'package:flutter/services.dart' show rootBundle;
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:yaml/yaml.dart';
import 'package:mustache_template/mustache_template.dart' as mustache;

class MacroTemplateService {
  final Map<String, dynamic> _templates = {};
  bool _inited = false;
  bool get inited => _inited;

  Future<void> init() async {
    try {
      final configString = await rootBundle.loadString('assets/config/uft_macro_list.yaml');
      final yamlMap = loadYaml(configString);

      if (yamlMap is! YamlMap) {
        throw const FormatException('Invalid YAML structure: root should be a map');
      }

      final templates = yamlMap['templates'];
      if (templates is YamlMap) {
        _templates.clear();
        templates.forEach((key, value) {
          if (value is YamlMap) {
            _templates[key] = {
              'header': value['header']?.toString() ?? '',
              'body': value['body']?.toString() ?? '',
              'footer': value['footer']?.toString() ?? '',
            };
          }
        });
      }
      _inited = true;
    } catch (e) {
      throw Exception('Failed to load macro templates: $e');
    }
  }

  Map<String, dynamic>? getTemplate(String templateName) {
    return _templates[templateName] is Map
        ? Map<String, dynamic>.from(_templates[templateName])
        : null;
  }

  String renderTemplate(
    List<String> templateList,
    Map<String, dynamic> context, {
    bool selectAll = false,
  }) {
    StringBuffer buffer = StringBuffer();
    for (var templateName in templateList) {
      Map<String, dynamic>? template = getTemplate('$templateName${selectAll ? '_ALL' : ''}');
      if (template == null) {
        Logger().warning("没有找到模板$templateName${selectAll ? '_ALL' : ''}");
        template = getTemplate(templateName);
        if (template == null) {
          throw Exception('Template $templateName not found');
        }
      }

      buffer.writeln(_render(template['body'], context));

      buffer.writeln();
    }

    return buffer.toString();
  }

  String _render(String template, Map<String, dynamic> context) {
    final t = mustache.Template(template);
    return t.renderString(context);
  }
}
