import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/framework/widgets/file_explorer_pane.dart';
import 'package:win_text_editor/framework/widgets/tab_view.dart';
import 'package:win_text_editor/menus/app_menu.dart';
import 'package:win_text_editor/framework/controllers/file_provider.dart';
import 'package:win_text_editor/framework/widgets/console_panel.dart';
import 'package:win_text_editor/modules/outline/controllers/outline_provider.dart';
import 'package:win_text_editor/modules/outline/widgets/outline_explorer.dart';

class AppScaffold extends StatefulWidget {
  const AppScaffold({super.key});

  @override
  State<AppScaffold> createState() => _AppScaffoldState();
}

class _AppScaffoldState extends State<AppScaffold> {
  bool _isFileExplorerCollapsed = false; // 控制文件树是否折叠

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider(create: (_) => FileProvider()),
        ChangeNotifierProvider(create: (_) => TabItemsController()),
        ChangeNotifierProvider(create: (_) => OutlineProvider()),
      ],
      child: Scaffold(
        backgroundColor: Colors.grey[100],
        body: Column(
          children: [
            const AppMenu(),
            Expanded(
              child: Row(
                children: [
                  // 文件树视图（可折叠）
                  AnimatedContainer(
                    duration: const Duration(milliseconds: 200),
                    width: _isFileExplorerCollapsed ? 48 : 200,
                    child: Material(
                      elevation: 2,
                      child: Column(
                        children: [
        // 折叠状态：显示展开按钮
        if (_isFileExplorerCollapsed)
          InkWell(
            onTap: () {
              setState(() {
                _isFileExplorerCollapsed = false;
              });
            },
            child: Container(
              height: 40,
              alignment: Alignment.center,
              child: const Icon(Icons.chevron_right, size: 20),
            ),
          ),
        // 展开状态：显示文件树
                          if (!_isFileExplorerCollapsed)
                            Expanded(
                              child: Consumer<TabItemsController>(
                                builder: (context, tabManager, child) {
                                  return FileExplorerPane(
                                    onFileDoubleTap:
                                        (path) => tabManager.handleFileDoubleTap(path, null),
                                    onFolderDoubleTap: (path) {
                                      if (path == 'toggle_collapse') {
                                        setState(() {
                                          _isFileExplorerCollapsed = true;
                                        });
                                      } else {
                                        tabManager.handleFolderDoubleTap(path);
                                      }
                                    },
                                  );
                                },
                              ),
                            ),
                        ],
                      ),
                    ),
                  ),
                  // 主内容区
                  Expanded(
                    child: Consumer<TabItemsController>(
                      builder:
                          (_, manager, __) =>
                              TabView(tabs: manager.tabs, currentTabId: manager.activeTabId),
                    ),
                  ),
                  // 右侧大纲视图
                  SizedBox(
                    width: 300,
                    child: Consumer<TabItemsController>(
                      builder: (context, tabManager, child) {
                        return OutlineExplorer(
                          onFileDoubleTap: (path, dynamic appendArg) {
                            // Handle file double tap if needed
                            tabManager.handleFileDoubleTap(path, appendArg);
                          },
                          onFolderDoubleTap: (path) {
                            tabManager.handleFolderDoubleTap(path);
                          },
                        );
                      },
                    ),
                  ),
                ],
              ),
            ),
            const ConsolePanel(),
          ],
        ),
      ),
    );
  }
}
