import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/file_provider.dart';
import 'package:win_text_editor/framework/services/file_path_manager.dart';
import 'package:win_text_editor/shared/components/file_explorer.dart';

class FileExplorerPane extends StatelessWidget {
  final Function(String)? onFileDoubleTap;
  final Function(String)? onFolderDoubleTap;

  const FileExplorerPane({super.key, this.onFileDoubleTap, this.onFolderDoubleTap});

  @override
  Widget build(BuildContext context) {
    final fileProvider = Provider.of<FileProvider>(context, listen: false);
    _loadLastOpenedFolder(fileProvider);

    return Consumer<FileProvider>(
      builder: (context, fileProvider, child) {
        return Material(
          elevation: 1,
          child: SizedBox(
            width: _calculateWidth(context, fileProvider),
            child: Column(
              children: [
                _buildHeader(context),
                Expanded(
                  child: FileExplorer(
                    onFileDoubleTap: onFileDoubleTap,
                    onFolderDoubleTap: onFolderDoubleTap,
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  Widget _buildHeader(BuildContext context) {
    return Container(
      height: 40,
      padding: const EdgeInsets.symmetric(horizontal: 8),
      decoration: BoxDecoration(
        color: Colors.grey[100],
        border: const Border(bottom: BorderSide(color: Colors.grey)),
      ),
      child: Row(
        children: [
        // 新增：折叠按钮
        IconButton(
          icon: const Icon(Icons.chevron_left, size: 20),
          tooltip: '折叠',
          onPressed: () {
            // 通过回调通知父组件折叠状态变化
            if (onFolderDoubleTap != null) {
              onFolderDoubleTap!('toggle_collapse');
            }
          },
        ),
          const Text('项目资源管理器', style: TextStyle(fontWeight: FontWeight.bold)),
          const Spacer(),
          IconButton(
            icon: const Icon(Icons.folder_open, size: 20),
            tooltip: '打开项目文件夹',
            onPressed: () => _openDirectory(context),
          ),
        ],
      ),
    );
  }

  double _calculateWidth(BuildContext context, FileProvider fileProvider) {
    final screenWidth = MediaQuery.of(context).size.width;
    final defaultWidth = screenWidth * 0.2; // 默认20%宽度
    return defaultWidth.clamp(200, 400); // 限制最小200，最大400
  }

  Future<void> _openDirectory(BuildContext context) async {
    final fileProvider = Provider.of<FileProvider>(context, listen: false);
    final String? selectedDirectory = await FilePicker.platform.getDirectoryPath();
    if (selectedDirectory != null) {
      await FilePathManager.saveLastOpenedFolder(selectedDirectory);
      await fileProvider.setRootPath(selectedDirectory);
    }
  }

  Future<void> _loadLastOpenedFolder(FileProvider fileProvider) async {
    if (fileProvider.rootPath != null && fileProvider.rootPath!.isNotEmpty) {
      return;
    }

    final String? lastOpenedFolder = await FilePathManager.getLastOpenedFolder();
    if (lastOpenedFolder != null) {
      await fileProvider.setRootPath(lastOpenedFolder);
    }
  }
}
