import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/module_router.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/framework/models/tab_model.dart';

class TabView extends StatefulWidget {
  final List<AppTab> tabs;
  final String? currentTabId;

  const TabView({super.key, required this.tabs, required this.currentTabId});

  @override
  State<TabView> createState() => _TabViewState();
}

class _TabViewState extends State<TabView> {
  @override
  Widget build(BuildContext context) {
    return Column(children: [_buildTabBar(context), Expanded(child: _buildTabContent())]);
  }

  Widget _buildTabBar(BuildContext context) {
    return SizedBox(
      height: 40,
      child: ListView.builder(
        scrollDirection: Axis.horizontal,
        itemCount: widget.tabs.length,
        itemBuilder: (ctx, index) {
          final tab = widget.tabs[index];
          return _TabItem(
            tab: tab,
            isActive: tab.id == widget.currentTabId,
            onClose: () => context.read<TabItemsController>().closeTab(tab.id),
            onTap: () => context.read<TabItemsController>().setActiveTab(tab.id),
          );
        },
      ),
    );
  }

  Widget _buildTabContent() {
    final tabManager = Provider.of<TabItemsController>(context, listen: false);
    final activeIndex = widget.tabs.indexWhere((t) => t.id == widget.currentTabId);
    if (activeIndex == -1) return const Center(child: Text('欢迎光临，敬请指导!'));

    return IndexedStack(
      index: activeIndex,
      children:
          widget.tabs.map((tab) {
            final controller = tabManager.getController<ChangeNotifier>(tab.id);
            return KeyedSubtree(key: ValueKey(tab.id), child: _buildTabItem(tab, controller));
          }).toList(),
    );
  }

  Widget _buildTabItem(AppTab tab, ChangeNotifier? controller) {
    return Container(
      decoration: const BoxDecoration(
        border: Border(top: BorderSide(color: Colors.lightBlue, width: 1)),
      ),
      child: ModuleRouter.buildWidgetForTab(tab, controller),
    );
  }
}

class _TabItem extends StatelessWidget {
  final AppTab tab;
  final bool isActive;
  final VoidCallback onClose;
  final VoidCallback onTap;

  const _TabItem({
    required this.tab,
    required this.isActive,
    required this.onClose,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        padding: const EdgeInsets.symmetric(horizontal: 16),
        decoration: BoxDecoration(color: isActive ? Colors.blue[100] : Colors.grey[200]),
        child: Row(
          children: [
            if (tab.icon != null) Icon(tab.icon, size: 16),
            if (tab.icon != null) const SizedBox(width: 4),
            Text(tab.title),
            const SizedBox(width: 8),
            IconButton(icon: const Icon(Icons.close, size: 16), onPressed: onClose),
          ],
        ),
      ),
    );
  }
}
