import 'package:flutter/material.dart';
import 'package:win_text_editor/menus/menu_constants.dart';

import 'menu_actions.dart';

class AppMenu extends StatelessWidget {
  const AppMenu({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 30,
      color: Colors.grey[200],
      child: Row(
        children: [
          _buildMenuButton(context, '文件', _buildFileMenuItems()),
          _buildMenuButton(context, '文本工具', _buildToolsMenuItems()),
          _buildMenuButton(context, 'UFT工具', _buildUftToolsMenuItems()),
          _buildMenuButton(context, '编辑', _buildEditMenuItems()),
          _buildMenuButton(context, '窗口', _buildWindowMenuItems()),
          _buildMenuButton(context, '帮助', _buildHelpMenuItems()),
        ],
      ),
    );
  }

  List<PopupMenuEntry<String>> _buildToolsMenuItems() {
    return [
      const PopupMenuItem<String>(
        value: MenuConstants.templateParser,
        child: ListTile(leading: Icon(Icons.auto_awesome_mosaic), title: Text('XML解析')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.contentSearch,
        child: ListTile(leading: Icon(Icons.search), title: Text('内容搜索')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.dataCompare,
        child: ListTile(leading: Icon(Icons.compare), title: Text('数据对比')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.dataFormat,
        child: ListTile(leading: Icon(Icons.date_range), title: Text('数据格式化')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.dataExtract,
        child: ListTile(leading: Icon(Icons.outbox), title: Text('XML数据提取')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.xmlSearch,
        child: ListTile(leading: Icon(Icons.find_in_page), title: Text('XML搜索')),
      ),
      const PopupMenuDivider(),
      const PopupMenuItem<String>(
        value: MenuConstants.demo,
        child: ListTile(leading: Icon(Icons.view_agenda), title: Text('Demo')),
      ),
    ];
  }

  List<PopupMenuEntry<String>> _buildUftToolsMenuItems() {
    return [
      const PopupMenuItem<String>(
        value: MenuConstants.memoryTable,
        child: ListTile(leading: Icon(Icons.list), title: Text('内存表')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.uftComponent,
        child: ListTile(leading: Icon(Icons.extension), title: Text('标准组件')),
      ),
      const PopupMenuItem<String>(
        value: MenuConstants.callFunction,
        child: ListTile(leading: Icon(Icons.functions), title: Text('功能号调用')),
      ),
      const PopupMenuDivider(),
      const PopupMenuItem<String>(
        value: MenuConstants.codeCreater,
        child: ListTile(leading: Icon(Icons.code), title: Text('代码生成器')),
      ),
    ];
  }

  Widget _buildMenuButton(BuildContext context, String label, List<PopupMenuEntry<String>> items) {
    return PopupMenuButton<String>(
      offset: const Offset(0, 30),
      child: Padding(padding: const EdgeInsets.symmetric(horizontal: 12.0), child: Text(label)),
      itemBuilder: (context) => items,
      onSelected: (value) => MenuActions.handleMenuAction(value, context),
    );
  }

  List<PopupMenuEntry<String>> _buildFileMenuItems() {
    return [
      // const PopupMenuItem<String>(value: MenuConstants.openFolder, child: Text('打开文件夹...')),
      const PopupMenuItem<String>(value: MenuConstants.save, child: Text('保存')),
      const PopupMenuItem<String>(value: MenuConstants.saveAs, child: Text('另存为...')),
      const PopupMenuItem<String>(value: MenuConstants.exit, child: Text('退出')),
    ];
  }

  List<PopupMenuEntry<String>> _buildEditMenuItems() {
    return [
      const PopupMenuItem<String>(value: MenuConstants.undo, child: Text('撤销')),
      const PopupMenuItem<String>(value: MenuConstants.redo, child: Text('重做')),
      const PopupMenuItem<String>(value: MenuConstants.cut, child: Text('剪切')),
      const PopupMenuItem<String>(value: MenuConstants.copy, child: Text('复制')),
      const PopupMenuItem<String>(value: MenuConstants.paste, child: Text('粘贴')),
    ];
  }

  List<PopupMenuEntry<String>> _buildWindowMenuItems() {
    return [
      const PopupMenuItem<String>(value: MenuConstants.minimize, child: Text('最小化')),
      const PopupMenuItem<String>(value: MenuConstants.maximize, child: Text('最大化')),
      const PopupMenuItem<String>(value: MenuConstants.close, child: Text('关闭')),
    ];
  }

  List<PopupMenuEntry<String>> _buildHelpMenuItems() {
    return [
      const PopupMenuItem<String>(value: MenuConstants.about, child: Text('关于')),
      const PopupMenuItem<String>(value: MenuConstants.help, child: Text('帮助')),
    ];
  }
}
