import 'package:collection/collection.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/framework/services/macro_template_service.dart';
import 'package:win_text_editor/modules/call_function/models/call_function.dart';
import 'package:win_text_editor/modules/call_function/services/call_function_service.dart';
import 'package:win_text_editor/modules/outline/models/code_partner.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:win_text_editor/shared/uft_std_fields/field_data_source.dart';
import 'package:win_text_editor/shared/base/base_content_controller.dart';

class CallFunctionController extends BaseContentController {
  CallFunction modle = CallFunction(
    functionType: '',
    functionNo: '',
    chineseName: '',
    inputParameters: [],
    outputParameters: [],
  );
  late DataGridSource inputSource;
  late DataGridSource outputSource;

  final MacroTemplateService templateService = MacroTemplateService();

  CallFunctionController() {
    inputSource = FieldsDataSource(
      [],
      onSelectionChanged: (index, isSelected) {
        updateInputSelection(index, isSelected);
      },
    );

    outputSource = FieldsDataSource(
      [],
      onSelectionChanged: (index, isSelected) {
        updateOutputSelection(index, isSelected);
      },
    );
  }

  void initTemplateService() {
    if (!templateService.inited) {
      templateService.init();
    }
  }

  String? genCodeString(List<String> macroList) {
    initTemplateService();
    StringBuffer sb = StringBuffer();

    //因子服务单独处理
    if (modle.functionType == 'uftfactorservice') {
      sb.write(templateService.renderTemplate(['因子服务'], modle.toMap()));
      return sb.toString();
    }

    //入参组件创建
    // for (final input in modle.inputParameters) {
    //   if (input.isSelected && input.type == CallFunction.componentType) {
    //     final component = modle.componentList?.firstWhereOrNull((c) => c.name == input.name);
    //     if (component != null) {
    //       sb.write(templateService.renderTemplate(['插入组件'], component.toMap()));
    //     }
    //   }
    // }
    sb.write(templateService.renderTemplate(macroList, modle.toMap()));
    //出参组件遍历
    // for (final output in modle.outputParameters) {
    //   if (output.isSelected && output.type == CallFunction.componentType) {
    //     final component = modle.componentList?.firstWhereOrNull((c) => c.name == output.name);
    //     if (component != null) {
    //       sb.write(templateService.renderTemplate(['遍历组件所有'], component.toMap()));
    //     }
    //   }
    // }
    return sb.toString();
  }

  @override
  Future<void> onOpenFile(String filePath, {dynamic appendArg}) async {
    Logger().info("Opening file: $filePath");
    try {
      modle = await CallFunctionService.parseXmlFile(filePath);

      // datagrid显示的数据源
      (inputSource as FieldsDataSource).updateData(modle.inputParameters);
      (outputSource as FieldsDataSource).updateData(modle.outputParameters);

      // Notify UI to update
      notifyListeners();
    } catch (e) {
      notifyListeners();
      Logger().error("Error opening file: $e");
    }
  }

  // 新增：更新字段选择状态
  void updateInputSelection(int index, bool isSelected) {
    final fields = (inputSource as FieldsDataSource).data;
    if (index >= 0 && index < fields.length) {
      fields[index].isSelected = isSelected;
      inputSource.notifyListeners();

      // 同步更新CallFunction
      modle.inputParameters[index].isSelected = isSelected;
      notifyListeners();
    }
  }

  void updateOutputSelection(int index, bool isSelected) {
    final fields = (outputSource as FieldsDataSource).data;
    if (index >= 0 && index < fields.length) {
      fields[index].isSelected = isSelected;
      outputSource.notifyListeners();

      // 同步更新CallFunction
      modle.outputParameters[index].isSelected = isSelected;
      notifyListeners();
    }
  }

  @override
  void onOpenFolder(String folderPath) {
    // 不支持打开文件夹
  }

  @override
  void onDropOutlineNode(OutlineNode node) {
    modle.codePartners.add(CodePartner.fromOutlineNode(node));
    notifyListeners();
  }
}
