import 'package:win_text_editor/modules/outline/models/code_partner.dart';
import 'package:win_text_editor/modules/uft_component/models/uft_component.dart';
import 'package:win_text_editor/shared/models/std_filed.dart';

class CallFunction {
  static const String componentType = 'COMPONENT';
  final String functionType;
  final String functionNo;
  final String chineseName;
  final List<Field> inputParameters;
  final List<Field> outputParameters;
  List<UftComponent>? componentList;
  List<UftComponent>? outComponentList;
  String? factorParam;
  final List<CodePartner> codePartners = [];

  CallFunction({
    required this.functionType,
    required this.functionNo,
    required this.chineseName,
    required this.inputParameters,
    required this.outputParameters,
    this.componentList,
    this.outComponentList,
    this.factorParam,
  });

  Map<String, dynamic> toMap() {
    return {
      'functionNo': functionNo,
      'chineseName': chineseName,
      'factorParam': factorParam ?? '',
      'input':
          inputParameters
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': inputParameters.indexOf(field) == inputParameters.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'selectedInput':
          inputParameters
              .where((field) => field.isSelected)
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': inputParameters.indexOf(field) == inputParameters.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'selectedOutput':
          outputParameters
              .where((field) => field.isSelected)
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': outputParameters.indexOf(field) == outputParameters.length - 1,
                },
              )
              .toList(),
      'output':
          outputParameters
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': outputParameters.indexOf(field) == outputParameters.length - 1,
                },
              )
              .toList(),
      'inputComps':
          componentList
              ?.map(
                (componen) => {
                  'id': componen.id,
                  'name': componen.name,
                  'chineseName': componen.chineseName,
                  'fields': componen.fields.map((field) => {'name': field.name}),
                },
              )
              .toList(),
    };
  }
}
