import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/call_function/controllers/call_function_controller.dart';
import 'package:win_text_editor/shared/uft_std_fields/field_data_source.dart';
import 'package:win_text_editor/shared/uft_std_fields/fields_data_grid.dart';

class CallFunctionLeftSide extends StatelessWidget {
  final CallFunctionController controller;
  const CallFunctionLeftSide({super.key, required this.controller});

  Widget _buildTextFieldRow(String label, String value, double width) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        Text('$label:'),
        SizedBox(
          width: width,
          child: TextField(
            controller: TextEditingController(text: value),
            readOnly: true,
            decoration: const InputDecoration(isDense: true, contentPadding: EdgeInsets.all(8)),
          ),
        ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        SizedBox(
          width: double.infinity,
          child: Card(
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: Wrap(
                spacing: 16,
                runSpacing: 8,
                children: [
                  _buildTextFieldRow('功能号', controller.modle.functionNo, 100),
                  _buildTextFieldRow('中文名', controller.modle.chineseName, 350),
                ],
              ),
            ),
          ),
        ),
        const SizedBox(height: 8),
        const Padding(
          padding: EdgeInsets.all(8.0),
          child: Text('入参', style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Expanded(
          flex: 6,
          child: FieldsDataGrid(
            fieldsSource: controller.inputSource as FieldsDataSource,
            onSelectionChanged: (index, isSelected) {
              controller.updateInputSelection(index, isSelected);
            },
          ),
        ),
        const Padding(
          padding: EdgeInsets.all(8.0),
          child: Text('出参', style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Expanded(
          flex: 4,
          child: FieldsDataGrid(
            fieldsSource: controller.outputSource as FieldsDataSource,
            onSelectionChanged: (index, isSelected) {
              controller.updateOutputSelection(index, isSelected);
            },
          ),
        ),
      ],
    );
  }
}
