// call_function_right_side.dart
import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/call_function/controllers/call_function_controller.dart';
import 'package:win_text_editor/shared/components/code_generation_components.dart';

class CallFunctionRightSide extends StatefulWidget {
  final CallFunctionController controller;
  final TextEditingController codeController;

  const CallFunctionRightSide({super.key, required this.controller, required this.codeController});

  @override
  State<CallFunctionRightSide> createState() => _CallFunctionRightSideState();
}

class _CallFunctionRightSideState extends State<CallFunctionRightSide> {
  String? _selectedOperation;

  @override
  void initState() {
    super.initState();
    widget.controller.initTemplateService();
    widget.controller.addListener(_updateDisplay);
  }

  @override
  void dispose() {
    widget.controller.removeListener(_updateDisplay);
    super.dispose();
  }

  void _updateDisplay() {
    if (_selectedOperation != null) {
      widget.codeController.text = widget.controller.genCodeString([_selectedOperation!]) ?? '';
    } else {
      widget.codeController.text = '';
    }
  }

  void _selectOperation(String? operation) {
    setState(() {
      _selectedOperation = operation;
      _updateDisplay();
    });
  }

  @override
  Widget build(BuildContext context) {
    final operations = ['普通调用', '事务调用'];

    return CodeGenerationSection(
      title: '生成代码',
      codeController: widget.codeController,
      onNodeDropped: (node) => widget.controller.onDropOutlineNode(node),
      child: OperationRadioSection(
        operations: operations,
        selectedOperation: _selectedOperation,
        onOperationSelected: _selectOperation,
      ),
    );
  }
}
