import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/modules/call_function/controllers/call_function_controller.dart';

import 'call_function_left_side.dart';
import 'call_function_right_side.dart';

class CallFunctionView extends StatefulWidget {
  final String tabId;
  const CallFunctionView({super.key, required this.tabId});

  @override
  State<CallFunctionView> createState() => _CallFunctionViewState();
}

class _CallFunctionViewState extends State<CallFunctionView> {
  late final CallFunctionController _controller;
  final TextEditingController _codeController = TextEditingController();
  bool _isControllerFromTabManager = false;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();

    final controllerFromManager = tabManager.getController(widget.tabId);
    if (controllerFromManager != null) {
      _controller = controllerFromManager;
      _isControllerFromTabManager = true;
    } else {
      _controller = CallFunctionController();
      _isControllerFromTabManager = false;
      tabManager.registerController(widget.tabId, _controller);
    }
  }

  @override
  void dispose() {
    if (!_isControllerFromTabManager) {
      _controller.dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: _controller,
      child: Consumer<CallFunctionController>(
        builder: (context, controller, child) {
          return Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                // 左侧部分 (50%)
                Expanded(flex: 5, child: CallFunctionLeftSide(controller: controller)),
                const SizedBox(width: 8),
                // 右侧部分 (50%)
                Expanded(
                  flex: 5,
                  child: CallFunctionRightSide(
                    codeController: _codeController,
                    controller: controller,
                  ),
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
