import 'package:win_text_editor/framework/common/constants.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/modules/code_creater/services/code_create_service.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:win_text_editor/shared/base/base_content_controller.dart';

class CodeCreaterController extends BaseContentController {
  final Map<String, List<String>> unMatchMap = {
    Constants.atomFunction: ['逻辑服务', '逻辑函数'],
    Constants.atomService: ['原子服务', '原子函数'],
    Constants.business: ['原子服务', '原子函数'],
    Constants.uftTable: [],
    Constants.component: [],
  };
  List<OutlineNode> _members = [];
  List<OutlineNode> get members => _members;
  String _selectedOperation = '原子函数';

  String get selectedOperation => _selectedOperation;

  set selectedOperation(String value) {
    final filtered =
        _members.where((node) => !(unMatchMap[node.value]?.contains(value) ?? false)).toList();
    _members = filtered; // 更新成员列表，移除不匹配的节点
    _selectedOperation = value;
  }

  void updateMembers(List<OutlineNode> newMembers) {
    _members = newMembers;
    notifyListeners(); // 通知监听者
  }

  @override
  void onOpenFile(String filePath, {dynamic appendArg}) {}

  @override
  void onOpenFolder(String folderPath) {}

  @override
  void onDropOutlineNode(OutlineNode node) {
    if (unMatchMap[node.value]?.contains(selectedOperation) ?? false) {
      Logger().error('当前节点不支持操作： $selectedOperation');
      return;
    }

    if (members.contains(node)) {
      Logger().error('不支持重复节点： ${node.title}');
      return;
    }

    //新节点重新设置默认操作
    node.selectedAction = CodeCreateService.getNodeActions(node.name)[0];

    members.add(node);

    notifyListeners();
  }

  Future<String> genCodeString() {
    return CodeCreateService.genCodeString(members, selectedOperation);
  }

  void handleActionTypeChange(int index, String newAction) {
    final memberName = members[index].name;

    if (newAction == "遍历记录") {
      members.add(
        OutlineNode(
          name: '${members[index].name}_END',
          title: members[index].title,
          value: '${members[index].value}_END',
          selectedAction: "遍历记录结束",
        ),
      );
    } else if (newAction == "遍历组件") {
      members.add(
        OutlineNode(
          name: '${members[index].name}_END',
          title: members[index].title,
          value: '${members[index].value}_END',
          selectedAction: "遍历组件结束",
        ),
      );
    } else {
      members.removeWhere((member) => member.name == '${memberName}_END');
    }

    // members[index].selectedAction = newAction;
    notifyListeners();
  }
}
