import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import '../controllers/content_search_controller.dart';
import 'directory_settings.dart';
import 'search_settings.dart';
import 'results_view.dart';

class ContentSearchView extends StatefulWidget {
  final String tabId;
  const ContentSearchView({super.key, required this.tabId});

  @override
  ContentSearchViewState createState() => ContentSearchViewState();
}

class ContentSearchViewState extends State<ContentSearchView> {
  late final ContentSearchController _controller;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();
    _controller = tabManager.getController(widget.tabId) ?? ContentSearchController();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: _controller,
      child: Padding(
        padding: const EdgeInsets.all(4.0),
        child: Column(
          children: [
            const DirectorySettings(), // 不再手动传递controller
            const SearchSettings(),
            Consumer<ContentSearchController>(
              builder: (context, controller, _) {
                return Column(
                  children: [
                    LinearProgressIndicator(
                      value: controller.progress / 100,
                      backgroundColor: Colors.grey[200],
                      valueColor: const AlwaysStoppedAnimation<Color>(Colors.green),
                      minHeight: 8,
                    ),
                  ],
                );
              },
            ),
            const Expanded(child: ResultsView()),
          ],
        ),
      ),
    );
  }
}
