import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/content_search/controllers/content_search_controller.dart';

class DirectorySettings extends StatefulWidget {
  const DirectorySettings({super.key});

  @override
  State<DirectorySettings> createState() => _DirectorySettingsState();
}

class _DirectorySettingsState extends State<DirectorySettings> {
  late TextEditingController _searchDirectoryController;
  late TextEditingController _fileTypeController;
  late TextEditingController _jumpFilesController;

  @override
  void initState() {
    super.initState();
    final controller = context.read<ContentSearchController>();
    _searchDirectoryController = TextEditingController(text: controller.searchDirectory);
    _fileTypeController = TextEditingController(text: controller.fileType);
    _jumpFilesController = TextEditingController(text: controller.jumpFiles);
  }

  @override
  void dispose() {
    _searchDirectoryController.dispose();
    _fileTypeController.dispose();
    _jumpFilesController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // 使用 Consumer 监听 ContentSearchController 的变化
    return Consumer<ContentSearchController>(
      builder: (context, controller, child) {
        // 同步 TextEditingController 的值
        if (_searchDirectoryController.text != controller.searchDirectory) {
          _searchDirectoryController.text = controller.searchDirectory;
        }
        if (_fileTypeController.text != controller.fileType) {
          _fileTypeController.text = controller.fileType;
        }

        return Card(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              children: [
                Expanded(
                  child: TextField(
                    controller: _searchDirectoryController,
                    decoration: const InputDecoration(
                      labelText: '搜索目录',
                      border: OutlineInputBorder(),
                    ),
                    onChanged: (value) => controller.searchDirectory = value,
                  ),
                ),

                const SizedBox(width: 8),
                IconButton(
                  icon: const Icon(Icons.folder_open),
                  onPressed: () async {
                    await controller.pickDirectory();
                    // 不需要手动更新 _searchDirectoryController.text，
                    // 因为 Consumer 会触发重建并自动同步
                  },
                ),

                const SizedBox(width: 8),
                SizedBox(
                  width: 100,
                  child: TextField(
                    controller: _fileTypeController,
                    decoration: const InputDecoration(
                      labelText: '文件类型',
                      border: OutlineInputBorder(),
                    ),
                    onChanged: (value) => controller.fileType = value,
                  ),
                ),

                const SizedBox(width: 8),
                SizedBox(
                  width: 200,
                  child: TextField(
                    controller: _jumpFilesController,
                    decoration: const InputDecoration(
                      labelText: '跳过文件(列表)',
                      border: OutlineInputBorder(),
                    ),
                    onChanged: (value) => controller.jumpFiles = value,
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}
