import 'package:file_picker/file_picker.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/modules/data_extract/models/search_result.dart';
import 'package:win_text_editor/modules/data_extract/models/xml_rule.dart';
import 'package:win_text_editor/modules/data_extract/services/xml_extract_service.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:win_text_editor/shared/base/base_content_controller.dart';

class DataExtractController extends BaseContentController {
  String _searchDirectory = '';
  String _fileType = '*.*';
  final List<SearchResult> _results = [];
  final List<XmlRule> _rules = [];
  final XmlExtractService _extractService = XmlExtractService();

  List<SearchResult> get results => _results;
  List<XmlRule> get rules => _rules;

  String get searchDirectory => _searchDirectory;
  String get fileType => _fileType;

  bool _isExtracting = false;

  bool onlyFileName = false;
  bool get isExtracting => _isExtracting;

  Future<void> executeExtraction() async {
    Logger().info("开始提取目录:$_searchDirectory, 文件名:$_fileType");
    if (_searchDirectory.isEmpty || _rules.isEmpty) return;

    _isExtracting = true;
    notifyListeners();

    _results.clear();
    notifyListeners();

    try {
      final newResults = await _extractService.extractFromDirectory(
        directory: _searchDirectory,
        fileType: _fileType,
        rule: _rules[0],
      );
      _results.addAll(newResults);
    } catch (e) {
      Logger().error("提取目录出错:$e");
      _results.add(
        SearchResult(rowNum: 1, filePath: 'Error', content: 'Extraction failed: $e', matchCount: 0),
      );
    } finally {
      _isExtracting = false;
      notifyListeners();
    }
  }

  set searchDirectory(String value) {
    _searchDirectory = value;
    notifyListeners();
  }

  set fileType(String value) {
    _fileType = value;
    notifyListeners();
  }

  Future<void> pickDirectory() async {
    final dir = await FilePicker.platform.getDirectoryPath();
    if (dir != null) {
      searchDirectory = dir;
    }
  }

  void setRule(XmlRule rule) {
    _rules.clear();
    rules.add(rule);
    notifyListeners();
  }

  void removeRule(int index) {
    _rules.removeAt(index);
    notifyListeners();
  }

  @override
  void onOpenFile(String filePath, {dynamic appendArg}) {
    // TODO: implement onOpenFile
  }

  @override
  void onOpenFolder(String folderPath) {
    searchDirectory = folderPath;
  }

  void cancelExtraction() {}

  @override
  void onDropOutlineNode(OutlineNode node) {
    // TODO: implement onDropOutlineNode
  }
}
