import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/data_extract/controllers/data_extract_controller.dart';

class Directory extends StatefulWidget {
  const Directory({super.key});

  @override
  State<Directory> createState() => _DirectoryState();
}

class _DirectoryState extends State<Directory> {
  late TextEditingController _searchDirectoryController;
  late TextEditingController _fileTypeController;

  @override
  void initState() {
    super.initState();
    final controller = context.read<DataExtractController>();
    _searchDirectoryController = TextEditingController(text: controller.searchDirectory);
    _fileTypeController = TextEditingController(text: controller.fileType);
  }

  @override
  void dispose() {
    _searchDirectoryController.dispose();
    _fileTypeController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<DataExtractController>(
      builder: (context, controller, child) {
        // 同步 TextEditingController 的值
        if (_searchDirectoryController.text != controller.searchDirectory) {
          _searchDirectoryController.text = controller.searchDirectory;
        }
        if (_fileTypeController.text != controller.fileType) {
          _fileTypeController.text = controller.fileType;
        }

        return Card(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              children: [
                Expanded(
                  child: TextField(
                    controller: _searchDirectoryController,
                    decoration: const InputDecoration(
                      labelText: '搜索目录',
                      border: OutlineInputBorder(),
                    ),
                    onChanged: (value) => controller.searchDirectory = value,
                  ),
                ),
                const SizedBox(width: 8),
                SizedBox(
                  width: 100,
                  child: TextField(
                    controller: _fileTypeController,
                    decoration: const InputDecoration(
                      labelText: '文件类型',
                      border: OutlineInputBorder(),
                    ),
                    onChanged: (value) => controller.fileType = value,
                  ),
                ),
                const SizedBox(width: 8),
                IconButton(
                  icon: const Icon(Icons.folder_open),
                  onPressed: () async {
                    await controller.pickDirectory();
                    // 不需要手动更新 _searchDirectoryController.text，
                    // 因为 Consumer 会触发重建并自动同步
                  },
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}
