import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/modules/data_format/controllers/data_format_controller.dart';
import 'package:win_text_editor/modules/data_format/widgets/grid_view.dart';
import 'package:win_text_editor/modules/data_format/widgets/format_text_panel.dart';

class DataFormatView extends StatefulWidget {
  final String tabId;
  const DataFormatView({super.key, required this.tabId});

  @override
  State<DataFormatView> createState() => _DataFormatViewState();
}

class _DataFormatViewState extends State<DataFormatView> {
  late final DataFormatController _controller;

  bool _isControllerFromTabManager = false;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();
    final controllerFromManager = tabManager.getController(widget.tabId);
    if (controllerFromManager != null) {
      _controller = controllerFromManager;
      _isControllerFromTabManager = true;
    } else {
      _controller = DataFormatController();
      _isControllerFromTabManager = false;
      tabManager.registerController(widget.tabId, _controller);
    }
  }

  @override
  void dispose() {
    if (!_isControllerFromTabManager) {
      _controller.dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider.value(value: _controller),
        ChangeNotifierProvider.value(value: _controller.gridController),
      ],
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Row(
          children: [
            Expanded(
              flex: 1,
              child: Card(child: DataGridView(controller: _controller.gridController)),
            ),
            // 右侧 FormatText 面板 (50%宽度)
            Expanded(flex: 1, child: FormatTextPanel(controller: _controller)),
          ],
        ),
      ),
    );
  }
}
