import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/data_format/controllers/data_format_controller.dart';
import 'package:win_text_editor/shared/components/editor_toolbar.dart';
import 'package:win_text_editor/shared/components/text_editor.dart';

class FormatTextPanel extends StatelessWidget {
  final DataFormatController controller;

  const FormatTextPanel({super.key, required this.controller});

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Column(
        children: [
          // 上部模板编辑器 (固定高度200px)
          SizedBox(
            height: 200,
            child: TextEditor(
              tabId: 'format_template',
              title: 'Mustache模板',
              onContentChanged: controller.setTemplateText,
            ),
          ),
          const SizedBox(height: 6),
          // 下部结果编辑器 (扩展高度)
          Expanded(
            child: ValueListenableBuilder<String>(
              valueListenable: controller.resultTextNotifier,
              builder: (context, resultText, _) {
                return TextEditor(
                  tabId: 'format_result',
                  title: '转换结果',
                  initialContent: resultText,
                  toolbarBuilder:
                      (context, state) => EditorToolbar(
                        title: '转换结果',
                        text: state.currentText,
                        isLoading: state.isLoading,
                        showOpenFileButton: false,
                        customButtons: [
                          ToolbarButtonConfig(
                            icon: Icons.code,
                            tooltip: '格式化',
                            onPressed: () => controller.applyTemplate(),
                          ),
                        ],
                        onCopyToClipboard: state.copyToClipboard,
                        onSaveFile: state.saveFile,
                      ),
                );
              },
            ),
          ),
        ],
      ),
    );
  }
}
