import 'package:win_text_editor/modules/outline/models/code_partner.dart';
import 'package:win_text_editor/shared/base/selectable_item.dart';
import 'package:win_text_editor/shared/models/std_filed.dart';

class Index implements SelectableItem {
  Index(this.indexName, this.isPrimary, this.indexFields, this.rule, [this.isSelected = false]);

  final String indexName;
  final bool isPrimary;
  final String indexFields;
  final String rule;
  @override
  bool isSelected;
  String get id => indexName;

  List<String> get fields => indexFields.split(',').map((e) => e.trim()).toList();
}

class MemoryTable {
  final String tableName;
  final List<Field> columns;
  final List<Index> indexes;
  final List<CodePartner> codePartners = [];

  MemoryTable({required this.tableName, required this.columns, required this.indexes});

  //获取第一个主键,如果有多个，则取选中的主键
  String? get keyName {
    Index? index;
    for (var i in indexes) {
      if (!i.isPrimary) continue;
      if (index == null) {
        index = i;
        if (i.isSelected) break;
      } else if (i.isSelected) {
        index = i;
      }
    }
    return index?.indexName;
  }

  //获取主键的字段
  List<String> get keyFields {
    var name = keyName;
    if (name == null || name.isEmpty) return [];
    for (var index in indexes) {
      if (index.indexName == name) {
        return index.fields;
      }
    }
    return [];
  }

  Index get selectIndexOrKey {
    for (var index in indexes) {
      if (index.isSelected) {
        return index;
      }
    }
    for (var index in indexes) {
      if (index.isPrimary) {
        return index;
      }
    }
    return indexes[0];
  }

  List<Field> get selectFields => columns.where((field) => field.isSelected).toList();

  Map<String, dynamic> toMap() {
    var index = selectIndexOrKey;
    return {
      'tableName': tableName,
      'fields':
          columns
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': columns.indexOf(field) == columns.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'selectedFields':
          selectFields
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': selectFields.indexOf(field) == selectFields.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'selectIndexOrKey': {
        'name': index.indexName,
        'isPrimary': index.isPrimary,
        'fields':
            index.fields.asMap().entries.map((entry) {
              return {
                'name': entry.value,
                'partnerName':
                    codePartners
                        .firstWhere(
                          (partner) => partner.fields.any((f) => f == entry.value),
                          orElse: () => CodePartner(name: null, fields: []),
                        )
                        .name,
                'isLast': entry.key == keyFields.length - 1,
              };
            }).toList(),
        'rule': index.rule,
      },
      'keyName': keyName,
      'keyFields':
          keyFields.asMap().entries.map((entry) {
            return {
              'name': entry.value,
              'partnerName':
                  codePartners
                      .firstWhere(
                        (partner) => partner.fields.any((f) => f == entry.value),
                        orElse: () => CodePartner(name: null, fields: []),
                      )
                      .name,
              'isLast': entry.key == keyFields.length - 1,
            };
          }).toList(),
    };
  }
}
