import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/modules/memory_table/controllers/index_data_source.dart';
import 'package:win_text_editor/modules/memory_table/controllers/memory_table_controller.dart';
import 'package:win_text_editor/shared/components/my_grid_column.dart';
import 'package:win_text_editor/shared/uft_std_fields/field_data_source.dart';
import 'package:win_text_editor/shared/uft_std_fields/fields_data_grid.dart';

class MemoryTableLeftSide extends StatelessWidget {
  final MemoryTableController controller;
  const MemoryTableLeftSide({super.key, required this.controller});

  Widget _buildTextFieldRow(String label, String value) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        Text('$label:'),
        SizedBox(
          width: 200,
          child: TextField(
            controller: TextEditingController(text: value),
            readOnly: true,
            decoration: const InputDecoration(isDense: true, contentPadding: EdgeInsets.all(8)),
          ),
        ),
      ],
    );
  }

  Widget _buildIndexesDataGrid(MemoryTableController controller) {
    final indexesSource = controller.indexesSource as IndexesDataSource;

    return Card(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            child: LayoutBuilder(
              builder: (context, constraints) {
                return SizedBox(
                  width: constraints.maxWidth,
                  child: SfDataGrid(
                    rowHeight: 32,
                    headerRowHeight: 32,
                    source: indexesSource,
                    gridLinesVisibility: GridLinesVisibility.both,
                    headerGridLinesVisibility: GridLinesVisibility.both,
                    columnWidthMode: ColumnWidthMode.fitByCellValue,
                    columns: [
                      GridColumn(
                        columnName: 'select',
                        label: Container(
                          alignment: Alignment.center,
                          color: Colors.grey[200],
                          child: const Text('选择', style: TextStyle(fontWeight: FontWeight.bold)),
                        ),
                        width: 60,
                      ),
                      MyGridColumn(columnName: 'indexName', label: '索引名称', minimumWidth: 120),
                      MyGridColumn(columnName: 'isPrimary', label: '是否主键', minimumWidth: 100),
                      MyGridColumn(columnName: 'indexFields', label: '索引字段', minimumWidth: 150),
                      MyGridColumn(columnName: 'rule', label: '规则', minimumWidth: 200),
                    ],
                    onCellTap: (details) {
                      if (details.column.columnName == 'select') {
                        final rowIndex = details.rowColumnIndex.rowIndex - 1;
                        if (rowIndex >= 0 && rowIndex < indexesSource.items.length) {
                          // 单选逻辑：先取消所有选择，再选中当前行
                          for (var i = 0; i < indexesSource.items.length; i++) {
                            indexesSource.toggleRowSelection(i, false);
                          }
                          indexesSource.toggleRowSelection(rowIndex, true);
                        }
                      }
                    },
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        SizedBox(
          width: double.infinity,
          child: Card(
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: Wrap(
                spacing: 16,
                runSpacing: 8,
                children: [
                  _buildTextFieldRow('名称', controller.tableName),
                  _buildTextFieldRow('中文名', controller.chineseName),
                  _buildTextFieldRow('对象编号', controller.objectId),
                ],
              ),
            ),
          ),
        ),
        const SizedBox(height: 8),
        const Padding(
          padding: EdgeInsets.all(8.0),
          child: Text('字段列表', style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Expanded(
          flex: 6,
          child: FieldsDataGrid(
            fieldsSource: controller.fieldsSource as FieldsDataSource,
            onSelectionChanged: (index, isSelected) {
              controller.updateFieldSelection(index, isSelected);
            },
          ),
        ),
        const Padding(
          padding: EdgeInsets.all(8.0),
          child: Text('索引列表', style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Expanded(flex: 4, child: _buildIndexesDataGrid(controller)),
      ],
    );
  }
}
