// memory_table_right_side.dart
import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/memory_table/controllers/memory_table_controller.dart';
import 'package:win_text_editor/shared/components/code_generation_components.dart';

class MemoryTableRightSide extends StatefulWidget {
  final MemoryTableController controller;
  final TextEditingController codeController;

  const MemoryTableRightSide({super.key, required this.controller, required this.codeController});

  @override
  State<MemoryTableRightSide> createState() => _MemoryTableRightSideState();
}

class _MemoryTableRightSideState extends State<MemoryTableRightSide> {
  String? _selectedOperation;

  @override
  void initState() {
    super.initState();
    widget.controller.initTemplateService();
    widget.controller.addListener(_updateDisplay);
  }

  @override
  void dispose() {
    widget.controller.removeListener(_updateDisplay);
    super.dispose();
  }

  void _updateDisplay() {
    if (_selectedOperation != null) {
      widget.codeController.text = widget.controller.genCodeString([_selectedOperation!]) ?? '';
    } else {
      widget.codeController.text = '';
    }
  }

  void _selectOperation(String? operation) {
    setState(() {
      _selectedOperation = operation;
      _updateDisplay();
    });
  }

  @override
  Widget build(BuildContext context) {
    final operations = ['获取记录', '获取记录数', '插入记录', '修改记录', '删除记录', '遍历记录'];

    return CodeGenerationSection(
      title: '生成代码',
      codeController: widget.codeController,
      onNodeDropped: (node) => widget.controller.onDropOutlineNode(node),
      child: OperationRadioSection(
        operations: operations,
        selectedOperation: _selectedOperation,
        onOperationSelected: _selectOperation,
      ),
    );
  }
}
