import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/modules/memory_table/controllers/memory_table_controller.dart';

import 'memory_table_left_side.dart';
import 'memory_table_right_side.dart';

class MemoryTableView extends StatefulWidget {
  final String tabId;
  const MemoryTableView({super.key, required this.tabId});

  @override
  State<MemoryTableView> createState() => _MemoryTableViewState();
}

class _MemoryTableViewState extends State<MemoryTableView> {
  late final MemoryTableController _controller;
  final TextEditingController _codeController = TextEditingController();
  bool _isControllerFromTabManager = false;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();

    final controllerFromManager = tabManager.getController(widget.tabId);
    if (controllerFromManager != null) {
      _controller = controllerFromManager;
      _isControllerFromTabManager = true;
    } else {
      _controller = MemoryTableController();
      _isControllerFromTabManager = false;
      tabManager.registerController(widget.tabId, _controller);
    }
  }

  @override
  void dispose() {
    if (!_isControllerFromTabManager) {
      _controller.dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: _controller,
      child: Consumer<MemoryTableController>(
        builder: (context, controller, child) {
          return Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                // 左侧部分 (50%)
                Expanded(flex: 5, child: MemoryTableLeftSide(controller: controller)),
                const SizedBox(width: 8),
                // 右侧部分 (50%)
                Expanded(
                  flex: 5,
                  child: MemoryTableRightSide(
                    codeController: _codeController,
                    controller: controller,
                  ),
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
