import 'package:path/path.dart' as path;
import 'package:win_text_editor/framework/common/constants.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:win_text_editor/modules/outline/services/component_service.dart';
import 'package:win_text_editor/modules/outline/services/uft_object_service.dart';

class CodePartner {
  final String? name;
  final List<String> fields;

  CodePartner({required this.name, required this.fields});

  factory CodePartner.fromOutlineNode(OutlineNode node) {
    String? name;
    List<String> fields = [];
    switch (node.value) {
      case Constants.uftTable:
        final List<String>? values = UftObjectService.uftObjectMap[node.title];
        if (values != null && values.isNotEmpty) {
          name = path.basenameWithoutExtension(values[0]);
          fields.addAll(values.sublist(1));
        }
        break;
      case Constants.component:
        name = node.name;
        final List<String>? values = ComponentService.componentFieldMap[node.name];
        if (values != null && values.isNotEmpty) {
          fields.addAll(values.sublist(1));
        }
        break;
    }
    return CodePartner(name: name, fields: fields);
  }
}
