import 'package:flutter/material.dart';
import 'package:win_text_editor/shared/components/tree_view.dart';

class OutlineNode implements TreeNode {
  @override
  final String name;

  @override
  String title = "";

  List<OutlineNode> _children = [];

  @override
  bool isDirectory;
  final bool isRoot;
  @override
  final int depth;
  @override
  List<OutlineNode> get children => _children;
  @override
  bool isExpanded;
  final int frequency;

  @override
  late String id;

  final String value;
  String? wordClass;

  String? selectedAction;
  String? path;

  OutlineNode({
    required this.name,
    required this.value,
    this.isDirectory = false,
    this.id = "",
    this.isRoot = false,
    this.depth = 0,
    this.frequency = 0,
    this.isExpanded = false,
    this.wordClass,
    List<OutlineNode>? children,
    this.title = "",
    this.selectedAction = "",
    this.path = "",
  }) : _children = children ?? [] {
    id = DateTime.now().microsecondsSinceEpoch.toRadixString(36) + title.hashCode.toRadixString(36);
  }

  OutlineNode copyWith({bool? isExpanded, List<OutlineNode>? children}) {
    return OutlineNode(
      id: id,
      name: name,
      value: value,
      title: title,
      isExpanded: isExpanded ?? this.isExpanded,
      isDirectory: isDirectory,
      children: children ?? this.children,
    );
  }

  // 获取文件图标数据
  @override
  IconData get iconData {
    if (isDirectory) {
      return Icons.folder;
    }

    return Icons.insert_drive_file;
  }

  set children(List<OutlineNode> nodes) {
    _children = nodes;
  }

  // 获取构建好的图标组件
  Widget get icon {
    return Icon(iconData, color: isDirectory ? Colors.amber[700] : Colors.blue);
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;
    return other is OutlineNode && other.id == id;
  }

  @override
  int get hashCode {
    return id.hashCode;
  }
}
