import 'dart:io';

import 'package:win_text_editor/framework/common/constants.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:xml/xml.dart';

class ComponentService {
  //组件索引
  static Map<String, List<String>> componentFieldMap = {};
  static String filePath = "";

  //初始化组件索引
  static Future<void> initComponentFieldMap(String rootPath) async {
    filePath = '$rootPath\\metadata\\component.xml';

    final componentFile = File(filePath);
    if (!await componentFile.exists()) {
      Logger().error('component.xml文件不存在');
      return;
    }

    componentFieldMap.clear();

    try {
      final content = await componentFile.readAsString();
      final document = XmlDocument.parse(content);

      // 查找所有items节点
      for (final item in document.findAllElements('items')) {
        final name = item.getAttribute('name');
        final chineseName = item.getAttribute('chineseName');
        if (name != null && chineseName != null) {
          componentFieldMap[name] = [chineseName];

          componentFieldMap[name]?.addAll(
            item
                .findElements('items')
                .map((item) => item.getAttribute('name'))
                .where((name) => name != null)
                .cast<String>(),
          );
        }
      }
    } catch (e) {
      Logger().error('加载Component失败: $e');
    }
  }

  //组合匹配
  static Map<String, String> matchComponent(String fieldName) {
    Map<String, String> matchComponents = {};

    componentFieldMap.forEach((key, value) {
      if (value.contains(fieldName)) matchComponents[key] = value[0];
    });

    return matchComponents;
  }

  static void loadComponent(String? fieldName, OutlineNode parentNode) {
    if (fieldName == null || fieldName.isEmpty) return;

    final matches = matchComponent(fieldName);
    matches.forEach(
      (key, value) => parentNode.children.add(
        OutlineNode(
          name: key,
          title: value,
          value: Constants.component,
          isDirectory: false,
          depth: 4,
          path: filePath,
        ),
      ),
    );
  }

  static List<OutlineNode> searchComponents(String searchQuery) {
    final List<OutlineNode> componentNodes = [];
    componentFieldMap.forEach((key, value) {
      if (key.contains(searchQuery) || value[0].contains(searchQuery)) {
        componentNodes.add(
          OutlineNode(
            name: key,
            title: value[0],
            value: Constants.component,
            isDirectory: false,
            depth: 4,
            path: filePath,
          ),
        );
      }
    });

    return componentNodes;
  }
}
