import 'dart:io';

import 'package:path/path.dart' as path;
import 'package:win_text_editor/framework/common/constants.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:xml/xml.dart';

class UftObjectService {
  //内存表索引
  static Map<String, List<String>> uftObjectMap = {};

  //初始化内存表列表
  static Future<void> initUftObjectMap(String rootPath) async {
    final uftStructureDir = Directory('$rootPath/uftstructure');
    if (!await uftStructureDir.exists()) {
      Logger().error('uftstructure目录不存在');
      return;
    }

    uftObjectMap.clear();

    try {
      // 遍历所有.uftstructure文件
      final uftStructureFiles =
          await uftStructureDir
              .list(recursive: true)
              .where((entity) => entity.path.endsWith('.uftstructure'))
              .cast<File>()
              .toList();

      for (final file in uftStructureFiles) {
        try {
          final content = await file.readAsString();
          final document = XmlDocument.parse(content);

          final fileName = file.path;
          final structureNode = document.findAllElements('structure:Structure').firstOrNull;

          if (structureNode == null) continue;

          final chineseName = structureNode.getAttribute('chineseName') ?? '未命名';

          uftObjectMap[chineseName] = [fileName];

          uftObjectMap[chineseName]?.addAll(
            structureNode
                .findElements('properties')
                .map((item) => item.getAttribute('id'))
                .where((name) => name != null)
                .cast<String>(),
          );
        } catch (e) {
          Logger().error('解析文件 ${file.path} 失败: $e');
        }
      }
    } catch (e) {
      Logger().error('加载UFT对象失败: $e');
      rethrow;
    }
  }

  // 私有方法：加载UFT对象
  static void loadUftObject(String? fieldName, OutlineNode parentNode) {
    if (fieldName == null || fieldName.isEmpty) return;

    uftObjectMap.forEach((key, value) {
      if (value.contains(fieldName)) {
        final tableName = path.basenameWithoutExtension(value[0]);
        parentNode.children.add(
          OutlineNode(
            name: tableName,
            title: key,
            value: Constants.uftTable,
            isDirectory: false, // 这些是叶子节点
            depth: 4,
            path: value[0],
          ),
        );
      }
    });
  }

  static List<OutlineNode> searchUftObjects(String searchQuery) {
    final List<OutlineNode> searchNodes = [];

    uftObjectMap.forEach((key, value) {
      final tableName = path.basenameWithoutExtension(value[0]);
      if (key.contains(searchQuery) || tableName.contains(searchQuery)) {
        searchNodes.add(
          OutlineNode(
            name: tableName,
            title: key,
            value: Constants.uftTable,
            isDirectory: false,
            depth: 4,
            path: value[0],
          ),
        );
      }
    });

    return searchNodes;
  }
}
