// grid_view_controller.dart
import 'package:win_text_editor/shared/models/template_node.dart';
import '../../../shared/base/safe_notifier.dart';

class GridViewController extends SafeNotifier {
  List<TemplateItem> _templateItems = [];
  List<TemplateItem> _filteredItems = [];
  bool _isFilterApplied = false;

  List<TemplateItem> get displayedItems => _isFilterApplied ? _filteredItems : _templateItems;
  bool get isFilterApplied => _isFilterApplied;
  List<TemplateItem> get templateItems => _templateItems;

  // 新增方法：更新节点引用
  List<TemplateNode>? _currentTreeNodes;
  void updateTreeNodesRef(List<TemplateNode> nodes) {
    _currentTreeNodes = nodes;
    safeNotify();
  }

  List<TemplateNode> getSelectedNodes() {
    if (_currentTreeNodes == null) return [];

    List<TemplateNode> selectedNodes = [];
    void traverse(TemplateNode node) {
      if (node.isChecked) selectedNodes.add(node);
      for (var child in node.children) {
        traverse(child);
      }
    }

    for (var node in _currentTreeNodes!) {
      traverse(node);
    }
    return selectedNodes;
  }

  void updateTemplateItems(List<TemplateItem> items) {
    _templateItems = items;
    safeNotify();
  }

  void applyFilter(List<TemplateItem> filteredItems) {
    _filteredItems = filteredItems;
    _isFilterApplied = true;
    safeNotify();
  }

  void clearFilter() {
    _isFilterApplied = false;
    safeNotify();
  }

  void updateItemValue({required String xPath, required newValue}) {
    //
  }
}
