// tree_view_controller.dart

import 'package:win_text_editor/shared/models/template_node.dart';
import '../../../shared/base/safe_notifier.dart';

class TreeViewController extends SafeNotifier {
  //根节点
  List<TemplateNode> _treeNodes = [];
  TemplateNode? _selectedNode;
  String? _currentParentPath;

  List<TemplateNode> get treeNodes => _treeNodes;
  TemplateNode? get selectedNode => _selectedNode;

  // 加载树视图，当文件路径改变时调用
  void updateTreeNodes(List<TemplateNode> nodes) {
    _treeNodes = nodes;
    safeNotify();
  }

  void selectTreeNode(TemplateNode node) {
    _selectedNode = node;
    safeNotify();
  }

  // 选择节点,多选时仅可选中同一层级的节点
  void toggleNodeCheck(TemplateNode node) {
    final parentPath = node.path.substring(0, node.path.lastIndexOf('/'));
    if (_currentParentPath != null && _currentParentPath != parentPath) {
      clearAllChecked();
    }
    node.isChecked = !node.isChecked;
    _currentParentPath = parentPath;
    safeNotify();
  }

  void clearAllChecked() {
    void traverse(TemplateNode node) {
      node.isChecked = false;
      for (var child in node.children) {
        traverse(child);
      }
    }

    for (var node in _treeNodes) {
      traverse(node);
    }
  }

  List<String> get selectedNodeNames {
    List<String> selectedNodeNames = [];

    void traverse(TemplateNode node) {
      if (node.isChecked) {
        selectedNodeNames.add(node.name);
      }
      for (var child in node.children) {
        traverse(child);
      }
    }

    for (var node in _treeNodes) {
      traverse(node);
    }

    return selectedNodeNames;
  }
}
