import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/template_parser/controllers/filter_controller.dart';

class TemplateFilterPanel extends StatefulWidget {
  final FilterController controller;

  const TemplateFilterPanel({super.key, required this.controller});

  @override
  State<TemplateFilterPanel> createState() => _TemplateFilterPanelState();
}

class _TemplateFilterPanelState extends State<TemplateFilterPanel> {
  late TextEditingController _textController;

  @override
  void initState() {
    super.initState();
    _textController = TextEditingController(text: widget.controller.filterValue);
  }

  @override
  void didUpdateWidget(covariant TemplateFilterPanel oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.controller.filterValue != _textController.text) {
      _textController.text = widget.controller.filterValue;
    }
  }

  @override
  void dispose() {
    _textController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<FilterController>(
      builder: (context, controller, _) {
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const SizedBox(height: 16),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8.0),
              child: Row(
                children: [
                  Expanded(
                    child: DropdownButtonFormField<String>(
                      decoration: const InputDecoration(
                        labelText: '过滤字段',
                        border: OutlineInputBorder(),
                      ),
                      items:
                          controller.availableFields.map((String value) {
                            return DropdownMenuItem<String>(value: value, child: Text(value));
                          }).toList(),
                      onChanged: (value) {
                        controller.selectedFilterField = value;
                      },
                      value: controller.selectedFilterField,
                    ),
                  ),
                  const SizedBox(width: 16),
                  SizedBox(
                    width: 120,
                    child: DropdownButtonFormField<String>(
                      decoration: const InputDecoration(
                        labelText: '匹配方式',
                        border: OutlineInputBorder(),
                      ),
                      items: const [
                        DropdownMenuItem(value: '==', child: Text('==')),
                        DropdownMenuItem(value: '>', child: Text('>')),
                        DropdownMenuItem(value: '<', child: Text('<')),
                        DropdownMenuItem(value: 'between', child: Text('between')),
                        DropdownMenuItem(value: 'in', child: Text('in')),
                      ],
                      onChanged: (value) {
                        controller.selectedFilterOperator = value;
                      },
                      value: controller.selectedFilterOperator,
                    ),
                  ),
                ],
              ),
            ),
            const SizedBox(height: 16),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8.0),
              child: SizedBox(
                height: 190,
                child: TextField(
                  maxLines: null,
                  expands: true,
                  decoration: const InputDecoration(
                    labelText: '过滤条件值',
                    border: OutlineInputBorder(),
                    alignLabelWithHint: true,
                  ),
                  controller: _textController,
                  onChanged: (value) {
                    widget.controller.filterValue = value;
                  },
                ),
              ),
            ),
            const SizedBox(height: 16),
            // 修改按钮部分代码
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  ElevatedButton(
                    onPressed:
                        controller.selectedFilterField != null &&
                                controller.selectedFilterOperator != null &&
                                controller.isFilterValid
                            ? () => controller.applyFilter()
                            : null,
                    child: const Text('过滤'),
                  ),
                  const SizedBox(width: 16),
                  ElevatedButton(
                    onPressed: () {
                      controller.clearFilter();
                    },
                    child: const Text('还原'),
                  ),
                ],
              ),
            ),
          ],
        );
      },
    );
  }
}
