import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/template_parser/controllers/tree_view_controller.dart';
import 'package:win_text_editor/shared/models/template_node.dart';
import 'package:win_text_editor/shared/components/tree_view.dart';

class TemplateTreeView extends StatelessWidget {
  const TemplateTreeView({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer<TreeViewController>(
      builder: (context, controller, _) {
        if (controller.treeNodes.isEmpty) {
          return const Center(child: Text('No XML data available'));
        }

        return TreeView(
          nodes: controller.treeNodes,
          config: const TreeViewConfig(
            showIcons: true,
            singleSelect: true,
            selectedColor: Colors.lightBlueAccent,
            icons: {'element': Icons.label_outline, 'attribute': Icons.code},
          ),
          onNodeTap: (node) {
            controller.selectTreeNode;
          },
          nodeBuilder: (context, node, isSelected, onTap) {
            return _buildTreeNode(node, isSelected, onTap, controller);
          },
        );
      },
    );
  }

  Widget _buildTreeNode(
    TreeNode node,
    bool isSelected,
    VoidCallback onTap,
    TreeViewController controller,
  ) {
    final templateNode = node as TemplateNode;
    final isAttribute = node.isAttribute;
    final isActuallySelected = controller.selectedNode?.id == templateNode.id;

    return Container(
      color: isActuallySelected ? Colors.lightBlueAccent.withOpacity(0.2) : Colors.transparent,
      child: Padding(
        padding: EdgeInsets.only(left: 12.0 * node.depth),
        child: ListTile(
          dense: true,
          leading: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              if (templateNode.children.isEmpty) // 仅在叶子节点显示复选框
                Transform.scale(
                  scale: 0.75,
                  child: Checkbox(
                    value: templateNode.isChecked,
                    onChanged: (value) {
                      if (value != null) {
                        controller.toggleNodeCheck(templateNode);
                      }
                    },
                  ),
                ),
              isAttribute
                  ? const Icon(Icons.code, size: 16, color: Colors.grey)
                  : const Icon(Icons.label_outline, size: 18, color: Colors.blue),
            ],
          ),
          title: Text(
            isAttribute ? templateNode.name.substring(1) : templateNode.name,
            style: TextStyle(
              color: isAttribute ? Colors.grey[600] : Colors.black,
              fontWeight: isAttribute ? FontWeight.normal : FontWeight.w500,
            ),
          ),
          trailing:
              templateNode.isRepeated
                  ? Text(
                    "(${templateNode.repeatCount.toString()})",
                    style: const TextStyle(color: Colors.grey),
                  )
                  : null,
          onTap: onTap,
        ),
      ),
    );
  }
}
