import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/modules/uft_component/models/uft_component.dart';
import 'package:win_text_editor/shared/base/my_sf_data_source.dart';

class ComponentSource extends MySfDataSource<UftComponent> {
  ComponentSource(
    List<UftComponent> uftComponents, {
    required Null Function(dynamic index, dynamic isSelected) onSelectionChanged,
  }) : super(uftComponents, onSelectionChanged: onSelectionChanged);

  @override
  List<DataGridRow> get rows =>
      items
          .map(
            (component) => DataGridRow(
              cells: [
                DataGridCell<int>(columnName: 'id', value: component.id),
                DataGridCell<String>(columnName: 'name', value: component.name),
                DataGridCell<String>(columnName: 'chineseName', value: component.chineseName),
              ],
            ),
          )
          .toList();

  @override
  DataGridRowAdapter buildRow(DataGridRow row) {
    final rowIndex = effectiveRows.indexOf(row);
    final isSelected = items[rowIndex].isSelected;

    return DataGridRowAdapter(
      color: isSelected ? Colors.lightBlue.withOpacity(0.3) : null,
      cells: [
        Container(
          alignment: Alignment.centerLeft,
          padding: const EdgeInsets.symmetric(horizontal: 8),
          child: Text(row.getCells()[0].value.toString(), overflow: TextOverflow.ellipsis),
        ),
        Container(
          alignment: Alignment.centerLeft,
          padding: const EdgeInsets.symmetric(horizontal: 8),
          child: Text(row.getCells()[1].value.toString(), overflow: TextOverflow.ellipsis),
        ),
        Container(
          alignment: Alignment.centerLeft,
          padding: const EdgeInsets.symmetric(horizontal: 8),
          child: Text(row.getCells()[2].value.toString(), overflow: TextOverflow.ellipsis),
        ),
      ],
    );
  }
}
