import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/framework/controllers/logger.dart';
import 'package:win_text_editor/framework/services/macro_template_service.dart';
import 'package:win_text_editor/modules/outline/models/code_partner.dart';
import 'package:win_text_editor/modules/outline/models/outline_node.dart';
import 'package:win_text_editor/modules/uft_component/controllers/component_source.dart';
import 'package:win_text_editor/modules/uft_component/models/uft_component.dart';
import 'package:win_text_editor/modules/uft_component/services/uft_component_service.dart';
import 'package:win_text_editor/shared/models/std_filed.dart';
import 'package:win_text_editor/shared/uft_std_fields/field_data_source.dart';
import 'package:win_text_editor/shared/base/base_content_controller.dart';

class UftComponentController extends BaseContentController {
  String? _errorMessage;
  String componentName = "";
  String chineseName = "";

  late DataGridSource fieldsSource;
  late DataGridSource componentsSource;
  final MacroTemplateService templateService = MacroTemplateService();

  // 新增：维护当前选中组件对象
  late UftComponent _currentUftComponent;

  UftComponentController() {
    // 初始化空数据
    final List<Field> initialFields = [];

    final List<UftComponent> initalComponents = [];

    componentsSource = ComponentSource(
      initalComponents,
      onSelectionChanged: (index, isSelected) {
        updateComponentSelection(index, isSelected);
      },
    );

    fieldsSource = FieldsDataSource(
      initialFields,
      onSelectionChanged: (index, isSelected) {
        updateFieldSelection(index, isSelected);
      },
    );

    // 初始化uftComponent
    _currentUftComponent = UftComponent(id: 0, name: '', chineseName: '', fields: initialFields);
  }

  String? get errorMessage => _errorMessage;

  // 新增：获取当前UftComponent
  UftComponent get currentUftComponent => _currentUftComponent;

  void initTemplateService() {
    if (!templateService.inited) {
      templateService.init();
    }
  }

  String? genCodeString(List<String> macroList) {
    initTemplateService();
    return templateService.renderTemplate(macroList, _currentUftComponent.toMap());
  }

  @override
  Future<void> onOpenFile(String filePath, {dynamic appendArg}) async {
    Logger().info("UftComponentController Opening file: $filePath");
    try {
      final components = await UftComponentService.parseComponentFile(
        filePath,
        filterName: appendArg,
      );

      // Update data sources
      (componentsSource as ComponentSource).updateData(components);

      // Clear any previous error
      _errorMessage = null;

      if (appendArg != null) {
        updateComponentSelection(0, true);
      }

      // Notify UI to update
      notifyListeners();
    } catch (e) {
      _errorMessage = e.toString();
      notifyListeners();
      Logger().error("Error UftComponentController opening file: $e");
    }
  }

  // 新增：更新字段选择状态
  void updateFieldSelection(int index, bool isSelected) {
    final fields = (fieldsSource as FieldsDataSource).data;
    if (index >= 0 && index < fields.length) {
      fields[index].isSelected = isSelected;
      fieldsSource.notifyListeners();

      // 同步更新MemoryTable
      _currentUftComponent.fields[index].isSelected = isSelected;
      notifyListeners();
    }
  }

  // 新增：更新索引选择状态

  @override
  void onOpenFolder(String folderPath) {
    // 不支持打开文件夹
  }

  @override
  void dispose() {
    super.dispose();
  }

  void updateComponentSelection(int index, bool isSelected) {
    if (index >= 0 && index < (componentsSource as ComponentSource).items.length) {
      // 更新当前选中的组件
      _currentUftComponent = (componentsSource as ComponentSource).items[index];

      // 更新字段数据源
      (fieldsSource as FieldsDataSource).updateData(_currentUftComponent.fields);

      // 通知UI更新
      notifyListeners();
    }
  }

  @override
  void onDropOutlineNode(OutlineNode node) {
    _currentUftComponent.codePartners.add(CodePartner.fromOutlineNode(node));
    notifyListeners();
  }
}
