import 'package:win_text_editor/modules/memory_table/models/memory_table.dart';
import 'package:win_text_editor/modules/outline/models/code_partner.dart';
import 'package:win_text_editor/shared/base/selectable_item.dart';
import 'package:win_text_editor/shared/models/std_filed.dart';

class UftComponent implements SelectableItem {
  final int id;
  final String name;
  final String chineseName;
  final List<Field> fields;
  List<Index>? indexes;
  @override
  bool isSelected;

  final List<CodePartner> codePartners = [];

  UftComponent({
    required this.id,
    required this.name,
    required this.chineseName,
    required this.fields,
    this.isSelected = false,
    this.indexes,
  });

  List<Field> get selectFields => fields.where((field) => field.isSelected).toList();

  Map<String, dynamic> toMap() {
    var index = indexes?.firstOrNull;
    return {
      'id': id,
      'name': name,
      'chineseName': chineseName,
      'fields':
          fields
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': fields.indexOf(field) == fields.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'selectedFields':
          selectFields
              .map(
                (field) => {
                  'id': field.id,
                  'name': field.name,
                  'chineseName': field.chineseName,
                  'type': field.type,
                  'isLast': selectFields.indexOf(field) == selectFields.length - 1,
                  'partnerName':
                      codePartners
                          .firstWhere(
                            (partner) => partner.fields.any((f) => f == field.name),
                            orElse: () => CodePartner(name: null, fields: []),
                          )
                          .name,
                },
              )
              .toList(),
      'hasIndex': indexes?.isNotEmpty ?? false,
      'index':
          index == null
              ? null
              : {
                'name': index.indexName,
                'fields':
                    index.fields.asMap().entries.map((entry) {
                      return {'name': entry.value, 'isLast': entry.key == index.fields.length - 1};
                    }).toList(),
                'rule': index.rule,
              },
    };
  }
}
