import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/modules/uft_component/controllers/component_source.dart';
import 'package:win_text_editor/shared/components/my_grid_column.dart';

class ComponentGrid extends StatefulWidget {
  final ComponentSource componentsSource;
  final Function(int index, bool isSelected)? onSelectionChanged;

  const ComponentGrid({super.key, required this.componentsSource, this.onSelectionChanged});

  @override
  State<ComponentGrid> createState() => ComponentGridState();
}

class ComponentGridState extends State<ComponentGrid> {
  final DataGridController _dataGridController = DataGridController();

  void scrollToIndex(int index) {
    _dataGridController.scrollToRow(index.toDouble());
    _dataGridController.selectedIndex = index;
  }

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            child: LayoutBuilder(
              builder: (context, constraints) {
                return SizedBox(
                  width: constraints.maxWidth,
                  child: SfDataGrid(
                    rowHeight: 32,
                    headerRowHeight: 32,
                    controller: _dataGridController,
                    source: widget.componentsSource,
                    gridLinesVisibility: GridLinesVisibility.both,
                    headerGridLinesVisibility: GridLinesVisibility.both,
                    columnWidthMode: ColumnWidthMode.fitByCellValue,
                    selectionMode: SelectionMode.single,
                    columns: [
                      MyGridColumn(columnName: 'id', label: '序号', minimumWidth: 80),
                      MyGridColumn(columnName: 'name', label: '名称', minimumWidth: 120),
                      MyGridColumn(columnName: 'chineseName', label: '中文名', minimumWidth: 120),
                    ],
                    onSelectionChanged: (addedRows, removedRows) {
                      if (addedRows.isNotEmpty) {
                        // 获取选中行的索引
                        final rowIndex = widget.componentsSource.effectiveRows.indexOf(
                          addedRows.first,
                        );

                        if (rowIndex >= 0 && rowIndex < widget.componentsSource.items.length) {
                          // 清除所有选择
                          for (var i = 0; i < widget.componentsSource.items.length; i++) {
                            widget.componentsSource.items[i].isSelected = (i == rowIndex);
                          }
                          widget.componentsSource.notifyListeners();
                          widget.onSelectionChanged?.call(rowIndex, true);
                        }
                      }
                    },
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );
  }
}
