import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/uft_component/controllers/component_source.dart';
import 'package:win_text_editor/modules/uft_component/controllers/uft_component_controller.dart';
import 'package:win_text_editor/modules/uft_component/widgets/component_grid.dart';
import 'package:win_text_editor/shared/uft_std_fields/field_data_source.dart';
import 'package:win_text_editor/shared/uft_std_fields/fields_data_grid.dart';

class UftComponentLeftSide extends StatefulWidget {
  final UftComponentController controller;
  const UftComponentLeftSide({super.key, required this.controller});

  @override
  State<UftComponentLeftSide> createState() => _UftComponentLeftSideState();
}

class _UftComponentLeftSideState extends State<UftComponentLeftSide> {
  final TextEditingController _searchController = TextEditingController();
  final GlobalKey<ComponentGridState> _gridKey = GlobalKey();
  final FocusNode _searchFocusNode = FocusNode(); // 新增焦点节点

  Widget _buildSearchField() {
    return Container(
      padding: const EdgeInsetsDirectional.only(start: 8, end: 80),
      child: TextField(
        controller: _searchController,
        focusNode: _searchFocusNode, // 添加焦点控制
        decoration: InputDecoration(
          isDense: true,
          contentPadding: const EdgeInsets.all(8),
          hintText: '',
          suffixIcon: IconButton(icon: const Icon(Icons.search), onPressed: _handleSearch),
        ),
        onSubmitted: (_) => _handleSearch(), // 添加回车键支持
      ),
    );
  }

  void _handleSearch() {
    final searchText = _searchController.text.trim();
    if (searchText.isEmpty) return;

    final source = widget.controller.componentsSource as ComponentSource;
    final items = source.items;

    // 模糊匹配查找
    int? foundIndex;
    for (var i = 0; i < items.length; i++) {
      if (items[i].chineseName.contains(searchText)) {
        foundIndex = i;
        break;
      }
    }

    if (foundIndex == null) {
      for (var i = 0; i < items.length; i++) {
        if (items[i].name.contains(searchText)) {
          foundIndex = i;
          break;
        }
      }
    }

    if (foundIndex != null) {
      // 更新选中状态
      for (var i = 0; i < items.length; i++) {
        items[i].isSelected = (i == foundIndex);
      }
      source.notifyListeners();

      // 定位到该行
      _gridKey.currentState?.scrollToIndex(foundIndex);

      // 更新字段表格
      widget.controller.updateComponentSelection(foundIndex, true);
    } else {
      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(content: Text('未找到匹配的记录')));
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      children: [
        _buildSearchField(),
        Expanded(
          flex: 3,
          child: ComponentGrid(
            key: _gridKey,
            componentsSource: widget.controller.componentsSource as ComponentSource,
            onSelectionChanged: (index, isSelected) {
              widget.controller.updateComponentSelection(index, isSelected);
            },
          ),
        ),
        Expanded(
          flex: 3,
          child: FieldsDataGrid(
            fieldsSource: widget.controller.fieldsSource as FieldsDataSource,
            onSelectionChanged: (index, isSelected) {
              widget.controller.updateFieldSelection(index, isSelected);
            },
          ),
        ),
      ],
    );
  }

  @override
  void dispose() {
    _searchController.dispose();
    _searchFocusNode.dispose(); // 释放焦点节点
    super.dispose();
  }
}
