// uft_component_right_side.dart
import 'package:flutter/material.dart';
import 'package:win_text_editor/modules/uft_component/controllers/uft_component_controller.dart';
import 'package:win_text_editor/shared/components/code_generation_components.dart';

class UftComponentRightSide extends StatefulWidget {
  final UftComponentController controller;
  final TextEditingController codeController;

  const UftComponentRightSide({super.key, required this.controller, required this.codeController});

  @override
  State<UftComponentRightSide> createState() => _UftComponentRightSideState();
}

class _UftComponentRightSideState extends State<UftComponentRightSide> {
  String? _selectedOperation;

  @override
  void initState() {
    super.initState();
    widget.controller.initTemplateService();
    widget.controller.addListener(_updateDisplay);
  }

  @override
  void dispose() {
    widget.controller.removeListener(_updateDisplay);
    super.dispose();
  }

  void _updateDisplay() {
    if (_selectedOperation != null) {
      widget.codeController.text = widget.controller.genCodeString([_selectedOperation!]) ?? '';
    } else {
      widget.codeController.text = '';
    }
  }

  void _selectOperation(String? operation) {
    setState(() {
      _selectedOperation = operation;
      _updateDisplay();
    });
  }

  @override
  Widget build(BuildContext context) {
    final operations = ['插入组件', '修改组件', '获取组件', '遍历组件', '组件大小', '尾部插入组件'];

    return CodeGenerationSection(
      title: '生成代码',
      codeController: widget.codeController,
      onNodeDropped: (node) => widget.controller.onDropOutlineNode(node),
      child: OperationRadioSection(
        operations: operations,
        selectedOperation: _selectedOperation,
        onOperationSelected: _selectOperation,
      ),
    );
  }
}
