import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';
import 'package:win_text_editor/modules/uft_component/controllers/uft_component_controller.dart';

import 'uft_component_left_side.dart';
import 'uft_component_right_side.dart';

class UftComponentView extends StatefulWidget {
  final String tabId;
  const UftComponentView({super.key, required this.tabId});

  @override
  State<UftComponentView> createState() => _UftComponentViewState();
}

class _UftComponentViewState extends State<UftComponentView> {
  late final UftComponentController _controller;
  final TextEditingController _codeController = TextEditingController();
  bool _isControllerFromTabManager = false;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();

    final controllerFromManager = tabManager.getController(widget.tabId);
    if (controllerFromManager != null) {
      _controller = controllerFromManager;
      _isControllerFromTabManager = true;
    } else {
      _controller = UftComponentController();
      _isControllerFromTabManager = false;
      tabManager.registerController(widget.tabId, _controller);
    }
  }

  @override
  void dispose() {
    if (!_isControllerFromTabManager) {
      _controller.dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: _controller,
      child: Consumer<UftComponentController>(
        builder: (context, controller, child) {
          return Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                // 左侧部分 (50%)
                Expanded(flex: 5, child: UftComponentLeftSide(controller: controller)),
                const SizedBox(width: 8),
                // 右侧部分 (50%)
                Expanded(
                  flex: 5,
                  child: UftComponentRightSide(
                    codeController: _codeController,
                    controller: controller,
                  ),
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
