import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/xml_search/controllers/xml_search_controller.dart';

class Directory extends StatefulWidget {
  const Directory({super.key});

  @override
  State<Directory> createState() => _DirectoryState();
}

class _DirectoryState extends State<Directory> {
  late TextEditingController _searchDirectoryController;

  @override
  void initState() {
    super.initState();
    final controller = context.read<XmlSearchController>();
    _searchDirectoryController = TextEditingController(text: controller.searchDirectory);
  }

  @override
  void dispose() {
    _searchDirectoryController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<XmlSearchController>(
      builder: (context, controller, child) {
        // 同步 TextEditingController 的值
        if (_searchDirectoryController.text != controller.searchDirectory) {
          _searchDirectoryController.text = controller.searchDirectory;
        }

        return Card(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              children: [
                Expanded(
                  child: TextField(
                    decoration: InputDecoration(
                      labelText: 'XML File',
                      hintText: 'Select an XML file',
                      suffixIcon: IconButton(
                        icon: const Icon(Icons.folder_open),
                        onPressed: controller.pickFile,
                      ),
                      border: const OutlineInputBorder(),
                    ),
                    controller: TextEditingController(text: controller.searchDirectory),
                    readOnly: true,
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}
