import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/modules/xml_search/controllers/xml_search_controller.dart';
import 'package:win_text_editor/modules/xml_search/widgets/condition_setting.dart';
import 'results_view.dart';
import 'directory.dart';
import 'package:win_text_editor/framework/controllers/tab_items_controller.dart';

class XmlSearchView extends StatefulWidget {
  final String tabId;
  const XmlSearchView({super.key, required this.tabId});

  @override
  XmlSearchViewState createState() => XmlSearchViewState();
}

class XmlSearchViewState extends State<XmlSearchView> {
  late final XmlSearchController _controller;

  get tabManager => Provider.of<TabItemsController>(context, listen: false);

  @override
  void initState() {
    super.initState();
    _controller = tabManager.getController(widget.tabId) ?? XmlSearchController();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider.value(
      value: _controller,
      child: Consumer<XmlSearchController>(
        builder: (context, controller, child) {
          return const Padding(
            padding: EdgeInsets.all(4.0),
            child: Column(
              children: [
                Directory(),
                Expanded(
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      // 左侧部分 (50%)
                      Expanded(flex: 3, child: ConditionSetting()),
                      SizedBox(width: 8),
                      // 右侧部分 (50%)
                      Expanded(flex: 7, child: ResultsView()),
                    ],
                  ),
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
