import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/shared/base/selectable_item.dart';

abstract class SelectableDataSource<T extends SelectableItem> extends DataGridSource {
  SelectableDataSource(this.items, {this.onSelectionChanged}) {
    _selectionNotifier = ValueNotifier(false);
  }

  List<T> items;
  final void Function(int index, bool isSelected)? onSelectionChanged;
  late final ValueNotifier<bool> _selectionNotifier;
  ValueNotifier<bool> get selectionNotifier => _selectionNotifier;

  void toggleAllSelection(bool value) {
    for (int i = 0; i < items.length; i++) {
      items[i].isSelected = value;
      onSelectionChanged?.call(i, value);
    }
    updateSelectionState();
    notifyListeners();
  }

  void toggleRowSelection(int index, bool? value) {
    final newValue = value ?? false;
    items[index].isSelected = newValue;
    updateSelectionState();
    notifyListeners();

    // 新增：触发回调
    onSelectionChanged?.call(index, newValue);
  }

  void updateSelectionState() {
    final allSelected = items.isNotEmpty && items.every((item) => item.isSelected);
    final someSelected = items.isNotEmpty && items.any((item) => item.isSelected);
    _selectionNotifier.value = allSelected || someSelected;
  }

  void updateDataGridSource() {
    updateSelectionState();
    notifyListeners();
  }

  void updateData(List<T> newItems) {
    items = newItems;
    notifyListeners();
  }
}
