import 'package:flutter/material.dart';

/// 工具栏按钮配置
class ToolbarButtonConfig {
  final IconData icon;
  final String tooltip;
  final bool isEnabled;
  final VoidCallback? onPressed;

  const ToolbarButtonConfig({
    required this.icon,
    required this.tooltip,
    this.isEnabled = true,
    this.onPressed,
  });
}

class EditorToolbar extends StatelessWidget {
  final String title;
  final String text;
  final bool isLoading;
  final bool showOpenFileButton;
  final bool showCopyButton;
  final bool showSaveButton;
  final List<ToolbarButtonConfig> customButtons;
  final VoidCallback? onOpenFile;
  final VoidCallback? onCopyToClipboard;
  final VoidCallback? onSaveFile;

  const EditorToolbar({
    super.key,
    required this.title,
    required this.text,
    this.isLoading = false,
    this.showOpenFileButton = true,
    this.showCopyButton = true,
    this.showSaveButton = true,
    this.customButtons = const [],
    this.onOpenFile,
    this.onCopyToClipboard,
    this.onSaveFile,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 40,
      padding: const EdgeInsets.symmetric(horizontal: 16),
      decoration: BoxDecoration(color: Colors.grey[300]),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Text(title, style: const TextStyle(fontWeight: FontWeight.bold)),
          _buildActionButtons(context),
        ],
      ),
    );
  }

  Widget _buildActionButtons(BuildContext context) {
    return Row(
      children: [
        if (showOpenFileButton)
          IconButton(
            icon: const Icon(Icons.folder_open, size: 20),
            tooltip: '打开文件',
            onPressed: isLoading ? null : onOpenFile,
          ),
        if (showCopyButton)
          IconButton(
            icon: const Icon(Icons.content_copy, size: 20),
            tooltip: '复制内容',
            onPressed: text.isEmpty ? null : onCopyToClipboard,
          ),
        if (showSaveButton)
          IconButton(
            icon: const Icon(Icons.save, size: 20),
            tooltip: '保存到文件',
            onPressed: text.isEmpty ? null : onSaveFile,
          ),
        // 添加自定义按钮
        ...customButtons.map(
          (button) => IconButton(
            icon: Icon(button.icon, size: 20),
            tooltip: button.tooltip,
            onPressed: button.isEnabled ? button.onPressed : null,
          ),
        ),
        if (isLoading)
          const Padding(
            padding: EdgeInsets.only(left: 8),
            child: SizedBox(
              width: 16,
              height: 16,
              child: CircularProgressIndicator(strokeWidth: 2),
            ),
          ),
      ],
    );
  }
}
