import 'dart:math';

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:win_text_editor/framework/controllers/file_provider.dart';
import 'package:win_text_editor/framework/models/file_node.dart';

import 'tree_view.dart';

class FileExplorer extends StatefulWidget {
  final Function(String)? onFileDoubleTap;
  final Function(String)? onFolderDoubleTap;

  const FileExplorer({super.key, this.onFileDoubleTap, this.onFolderDoubleTap});

  @override
  State<FileExplorer> createState() => _FileExplorerState();
}

class _FileExplorerState extends State<FileExplorer> {
  final ScrollController _scrollController = ScrollController(); // 添加ScrollController

  @override
  void dispose() {
    _scrollController.dispose(); // 记得销毁controller
    super.dispose();
  }

  // 动态计算总宽度（根据层级深度调整）
  double calculateTotalWidth(BuildContext context, FileProvider fileProvider) {
    final maxDepth = _getMaxDepth(fileProvider.fileNodes);
    return maxDepth * 60 + MediaQuery.of(context).size.width * 0.2;
  }

  int _getMaxDepth(List<FileNode> nodes) {
    int maxDepth = 0;
    for (final node in nodes) {
      if (node.isDirectory && node.isExpanded) {
        maxDepth = max(maxDepth, _getMaxDepth(node.children) + 1);
      }
    }
    return maxDepth;
  }

  @override
  Widget build(BuildContext context) {
    final fileProvider = Provider.of<FileProvider>(context);

    return Scrollbar(
      controller: _scrollController, // 指定controller
      thumbVisibility: true,
      child: SingleChildScrollView(
        controller: _scrollController, // 使用同一个controller
        scrollDirection: Axis.horizontal,
        child: Container(
          color: Colors.white,
          child: SizedBox(
            width: calculateTotalWidth(context, fileProvider),
            child: TreeView(
              nodes: fileProvider.fileNodes,
              config: const TreeViewConfig(showIcons: true, lazyLoad: true),
              onNodeTap: (node) => _handleNodeTap(context, node as FileNode),
              onNodeDoubleTap: (node) => _handleNodeDoubleTap(node as FileNode),
            ),
          ),
        ),
      ),
    );
  }

  Future<void> _handleNodeTap(BuildContext context, FileNode node) async {
    final fileProvider = Provider.of<FileProvider>(context, listen: false);
    if (node.isDirectory) {
      await fileProvider.loadDirectoryContents(node);
    }
  }

  void _handleNodeDoubleTap(TreeNode node) {
    final fileNode = node as FileNode;
    if (fileNode.isDirectory && widget.onFolderDoubleTap != null) {
      widget.onFolderDoubleTap!(fileNode.path);
    } else if (!fileNode.isDirectory && widget.onFileDoubleTap != null) {
      widget.onFileDoubleTap!(fileNode.path);
    }
  }
}
