import 'package:flutter/material.dart';
import 'package:pluto_grid/pluto_grid.dart';

class MyPlutoDropdownColumn extends PlutoColumn {
  final List<String> Function(Key rowKey)? optionsBuilder;

  MyPlutoDropdownColumn({
    required String title,
    required String field,
    this.optionsBuilder,
    double width = 200,
    bool enableRowChecked = false,
    bool enableSorting = false,
    bool autoSize = false,
    PlutoColumnTextAlign textAlign = PlutoColumnTextAlign.start,
  }) : super(
         title: title,
         field: field,
         type: PlutoColumnType.text(defaultValue: ''),
         width: width,
         enableRowChecked: enableRowChecked,
         enableContextMenu: false,
         enableEditingMode: true,
         enableSorting: enableSorting,
         readOnly: false,
         backgroundColor: Colors.grey[100],
         textAlign: textAlign,
         titleTextAlign: PlutoColumnTextAlign.center,
         suppressedAutoSize: !autoSize,
         renderer: (rendererContext) {
           final rowKey = rendererContext.row.key;
           final options = optionsBuilder?.call(rowKey) ?? [];
           final currentValue = rendererContext.row.cells[field]!.value.toString();

           return DropdownButton<String>(
             value:
                 options.contains(currentValue)
                     ? currentValue
                     : (options.isNotEmpty ? options.first : ''),
             items:
                 options
                     .map((value) => DropdownMenuItem(value: value, child: Text(value)))
                     .toList(),
             onChanged: (newValue) {
               if (newValue != null) {
                 rendererContext.stateManager.changeCellValue(
                   rendererContext.row.cells[field]!,
                   newValue,
                 );
               }
             },
             // 美化样式
             icon: const Padding(
               padding: EdgeInsets.only(right: 8.0),
               child: Icon(Icons.arrow_drop_down, size: 24),
             ),
             iconSize: 24,
             isExpanded: true,
             underline: Container(), // 移除下划线
             style: const TextStyle(fontSize: 14, color: Colors.black87),
             dropdownColor: Colors.white,
             elevation: 2,
             borderRadius: BorderRadius.circular(4),
             // 对齐方式
             alignment: Alignment.centerLeft,
           );
         },
       );
}
