import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_datagrid/datagrid.dart';
import 'package:win_text_editor/shared/base/my_sf_data_source.dart';
import 'package:win_text_editor/shared/models/std_filed.dart';

class FieldsDataSource extends MySfDataSource<Field> {
  FieldsDataSource(
    List<Field> fields, {
    required Null Function(dynamic index, dynamic isSelected) onSelectionChanged,
  }) : super(fields, onSelectionChanged: onSelectionChanged);

  @override
  List<DataGridRow> get rows =>
      items
          .map(
            (field) => DataGridRow(
              cells: [
                DataGridCell<bool>(columnName: 'select', value: field.isSelected),
                DataGridCell<String>(columnName: 'id', value: field.id),
                DataGridCell<String>(columnName: 'name', value: field.name),
                DataGridCell<String>(columnName: 'chineseName', value: field.chineseName),
                DataGridCell<String>(columnName: 'type', value: field.type),
              ],
            ),
          )
          .toList();

  get data => items;

  @override
  DataGridRowAdapter buildRow(DataGridRow row) {
    final rowIndex = effectiveRows.indexOf(row);
    return DataGridRowAdapter(
      cells:
          row.getCells().map<Widget>((cell) {
            if (cell.columnName == 'select') {
              return Center(
                child: Transform.scale(
                  scale: 0.75,
                  child: Checkbox(
                    value: items[rowIndex].isSelected,
                    onChanged: (value) => toggleRowSelection(rowIndex, value),
                  ),
                ),
              );
            }
            return Container(
              alignment: Alignment.centerLeft,
              padding: const EdgeInsets.symmetric(horizontal: 8),
              child: Text(cell.value.toString(), overflow: TextOverflow.ellipsis),
            );
          }).toList(),
    );
  }
}
